==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectAdms.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectadms_h
#define objectadms_h
#include <admsObject/admsH.h>
typedef enum {
  adms_adms_enumeration_datatypename__star,
  adms_adms_enumeration_datatypename_adms,
  adms_adms_enumeration_datatypename_admsattribute,
  adms_adms_enumeration_datatypename_admselement,
  adms_adms_enumeration_datatypename_admsmain,
  adms_adms_enumeration_datatypename_admst,
  adms_adms_enumeration_datatypename_admsttransform,
  adms_adms_enumeration_datatypename_admstvariable,
  adms_adms_enumeration_datatypename_analog,
  adms_adms_enumeration_datatypename_analogfunction,
  adms_adms_enumeration_datatypename_assignment,
  adms_adms_enumeration_datatypename_attribute,
  adms_adms_enumeration_datatypename_block,
  adms_adms_enumeration_datatypename_blockvariable,
  adms_adms_enumeration_datatypename_branch,
  adms_adms_enumeration_datatypename_branchalias,
  adms_adms_enumeration_datatypename_callfunction,
  adms_adms_enumeration_datatypename_case,
  adms_adms_enumeration_datatypename_caseitem,
  adms_adms_enumeration_datatypename_conditional,
  adms_adms_enumeration_datatypename_contribution,
  adms_adms_enumeration_datatypename_discipline,
  adms_adms_enumeration_datatypename_enumeration,
  adms_adms_enumeration_datatypename_evaluation,
  adms_adms_enumeration_datatypename_expression,
  adms_adms_enumeration_datatypename_function,
  adms_adms_enumeration_datatypename_instance,
  adms_adms_enumeration_datatypename_instancenode,
  adms_adms_enumeration_datatypename_instanceofadmsttransform,
  adms_adms_enumeration_datatypename_instanceparameter,
  adms_adms_enumeration_datatypename_integer,
  adms_adms_enumeration_datatypename_jacobian,
  adms_adms_enumeration_datatypename_lexval,
  adms_adms_enumeration_datatypename_list,
  adms_adms_enumeration_datatypename_mapply_binary,
  adms_adms_enumeration_datatypename_mapply_ternary,
  adms_adms_enumeration_datatypename_mapply_unary,
  adms_adms_enumeration_datatypename_math,
  adms_adms_enumeration_datatypename_module,
  adms_adms_enumeration_datatypename_nature,
  adms_adms_enumeration_datatypename_nilled,
  adms_adms_enumeration_datatypename_node,
  adms_adms_enumeration_datatypename_nodealias,
  adms_adms_enumeration_datatypename_number,
  adms_adms_enumeration_datatypename_path,
  adms_adms_enumeration_datatypename_probe,
  adms_adms_enumeration_datatypename_production,
  adms_adms_enumeration_datatypename_range,
  adms_adms_enumeration_datatypename_real,
  adms_adms_enumeration_datatypename_simulator,
  adms_adms_enumeration_datatypename_source,
  adms_adms_enumeration_datatypename_string,
  adms_adms_enumeration_datatypename_subexpression,
  adms_adms_enumeration_datatypename_variable,
  adms_adms_enumeration_datatypename_whileloop,
  adms_adms_enumeration_datatypename_yaccval
} e_adms_datatypename;
win32_interface char* adms_adms_tostring_datatypename_impl (p_admsttransform myadmsttransform,e_adms_datatypename e);
win32_interface e_adms_datatypename adms_adms_fromstring_datatypename_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_adms_enumeration_seen_no,
  adms_adms_enumeration_seen_yes
} e_adms_seen;
win32_interface char* adms_adms_tostring_seen_impl (p_admsttransform myadmsttransform,e_adms_seen e);
win32_interface e_adms_seen adms_adms_fromstring_seen_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_adms_enumeration_freed_no,
  adms_adms_enumeration_freed_yes
} e_adms_freed;
win32_interface char* adms_adms_tostring_freed_impl (p_admsttransform myadmsttransform,e_adms_freed e);
win32_interface e_adms_freed adms_adms_fromstring_freed_impl (p_admsttransform myadmsttransform,char*token);
struct s_adms {
  e_adms_datatypename _datatypename;
  int _datatypename_isdefault : 1;
  e_adms_seen _seen;
  int _seen_isdefault : 1;
  e_adms_freed _freed;
  int _freed_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_adms_getuid (p_adms myadms);
win32_interface gboolean adms_adms_cmp (p_adms myadms,p_adms refadms);
#define adms_adms_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_adms_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_adms_new_impl (p_adms arguments[]);
win32_interface p_adms adms_adms_impl (void* member);
#define adms_adms(member) ((p_adms) (member))
#define adms_adms_new adms_adms_new_1
#define adms_adms_isdefault_datatypename(adms) (adms_adms(adms)->_datatypename_isdefault)
#define adms_adms_valueof_datatypename(adms) (adms_adms(adms)->_datatypename)
#define adms_adms_isdefault_seen(adms) (adms_adms(adms)->_seen_isdefault)
#define adms_adms_valueof_seen(adms) (adms_adms(adms)->_seen)
#define adms_adms_isdefault_freed(adms) (adms_adms(adms)->_freed_isdefault)
#define adms_adms_valueof_freed(adms) (adms_adms(adms)->_freed)
#define adms_adms_valueto_datatypename(a,b) ((p_adms)a)->_datatypename=(b)
win32_interface void adms_adms_valueto_datatypename_impl (p_adms myadms,e_adms_datatypename _datatypename);
#define adms_adms_valueto_seen(a,b) ((p_adms)a)->_seen=(b)
win32_interface void adms_adms_valueto_seen_impl (p_adms myadms,e_adms_seen _seen);
#define adms_adms_valueto_freed(a,b) ((p_adms)a)->_freed=(b)
win32_interface void adms_adms_valueto_freed_impl (p_adms myadms,e_adms_freed _freed);
#endif /* objectadms_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectAdms.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectadms_h
#define objectadms_h
#include <admsObject/admsH.h>
typedef enum {
  adms_adms_enumeration_datatypename__empty,
  adms_adms_enumeration_datatypename__star,
  adms_adms_enumeration_datatypename_adms,
  adms_adms_enumeration_datatypename_admsmain,
  adms_adms_enumeration_datatypename_admst,
  adms_adms_enumeration_datatypename_admstpath,
  adms_adms_enumeration_datatypename_admstpathevaluate,
  adms_adms_enumeration_datatypename_admstpathgoto,
  adms_adms_enumeration_datatypename_admstpathparser,
  adms_adms_enumeration_datatypename_admsttext,
  adms_adms_enumeration_datatypename_admsttransform,
  adms_adms_enumeration_datatypename_admsttransformattribute,
  adms_adms_enumeration_datatypename_admstvariable,
  adms_adms_enumeration_datatypename_analog,
  adms_adms_enumeration_datatypename_analogfunction,
  adms_adms_enumeration_datatypename_assignment,
  adms_adms_enumeration_datatypename_attribute,
  adms_adms_enumeration_datatypename_block,
  adms_adms_enumeration_datatypename_blockvariable,
  adms_adms_enumeration_datatypename_branch,
  adms_adms_enumeration_datatypename_branchalias,
  adms_adms_enumeration_datatypename_callfunction,
  adms_adms_enumeration_datatypename_case,
  adms_adms_enumeration_datatypename_caseitem,
  adms_adms_enumeration_datatypename_conditional,
  adms_adms_enumeration_datatypename_contribution,
  adms_adms_enumeration_datatypename_discipline,
  adms_adms_enumeration_datatypename_enumeration,
  adms_adms_enumeration_datatypename_evaluation,
  adms_adms_enumeration_datatypename_expression,
  adms_adms_enumeration_datatypename_function,
  adms_adms_enumeration_datatypename_instance,
  adms_adms_enumeration_datatypename_instancenode,
  adms_adms_enumeration_datatypename_instanceofadmsttransform,
  adms_adms_enumeration_datatypename_instanceparameter,
  adms_adms_enumeration_datatypename_integer,
  adms_adms_enumeration_datatypename_jacobian,
  adms_adms_enumeration_datatypename_lexval,
  adms_adms_enumeration_datatypename_list,
  adms_adms_enumeration_datatypename_mapply_binary,
  adms_adms_enumeration_datatypename_mapply_ternary,
  adms_adms_enumeration_datatypename_mapply_unary,
  adms_adms_enumeration_datatypename_math,
  adms_adms_enumeration_datatypename_module,
  adms_adms_enumeration_datatypename_nature,
  adms_adms_enumeration_datatypename_nilled,
  adms_adms_enumeration_datatypename_node,
  adms_adms_enumeration_datatypename_nodealias,
  adms_adms_enumeration_datatypename_number,
  adms_adms_enumeration_datatypename_path,
  adms_adms_enumeration_datatypename_probe,
  adms_adms_enumeration_datatypename_quark,
  adms_adms_enumeration_datatypename_range,
  adms_adms_enumeration_datatypename_real,
  adms_adms_enumeration_datatypename_simulator,
  adms_adms_enumeration_datatypename_source,
  adms_adms_enumeration_datatypename_string,
  adms_adms_enumeration_datatypename_subexpression,
  adms_adms_enumeration_datatypename_variable,
  adms_adms_enumeration_datatypename_void,
  adms_adms_enumeration_datatypename_whileloop,
  adms_adms_enumeration_datatypename_yaccval
} e_adms_datatypename;
win32_interface char* adms_adms_tostring_datatypename_impl (p_admsttransform myadmsttransform,e_adms_datatypename e);
win32_interface e_adms_datatypename adms_adms_fromstring_datatypename_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_adms_enumeration_seen_no,
  adms_adms_enumeration_seen_yes
} e_adms_seen;
win32_interface char* adms_adms_tostring_seen_impl (p_admsttransform myadmsttransform,e_adms_seen e);
win32_interface e_adms_seen adms_adms_fromstring_seen_impl (p_admsttransform myadmsttransform,char*token);
struct s_adms {
  e_adms_datatypename _datatypename;
  int _datatypename_isdefault : 1;
  e_adms_seen _seen;
  int _seen_isdefault : 1;
  int _used;
  int _used_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_adms_uid (p_adms myadms);
win32_interface int adms_adms_cmp (p_adms myadms,p_adms refadms);
win32_interface p_adms adms_adms_new_impl (p_adms arguments[]);
#define adms_adms(member) ((p_adms) (member))
#define adms_adms_isdefault_datatypename(adms) (adms_adms(adms)->_datatypename_isdefault)
#define adms_adms_valueof_datatypename(adms) (adms_adms(adms)->_datatypename)
#define adms_adms_isdefault_seen(adms) (adms_adms(adms)->_seen_isdefault)
#define adms_adms_valueof_seen(adms) (adms_adms(adms)->_seen)
#define adms_adms_isdefault_used(adms) (adms_adms(adms)->_used_isdefault)
#define adms_adms_valueof_used(adms) (adms_adms(adms)->_used)
win32_interface inline void adms_adms_valueto_datatypename (p_adms myadms,e_adms_datatypename _datatypename);
win32_interface inline void adms_adms_valueto_seen (p_adms myadms,e_adms_seen _seen);
win32_interface inline void adms_adms_valueto_used (p_adms myadms,int _used);
win32_interface inline void adms_adms_free(p_adms myadms);
#endif /* objectadms_h */
